@@ -55,7 +55,7 @@ class NotificationAdmin(admin.ModelAdmin):
         return False
 
     def send(self, request, queryset):
-        return NotImplemented
+        raise NotImplementedError
 
     def read(self, request, queryset):
         if queryset.count() > 0:
@@ -69,14 +69,6 @@ class NotificationAdmin(admin.ModelAdmin):
 
         self.message_user(request, "Notification ignored", level=messages.SUCCESS)
 
-    @display(description=_("Template"))
-    def get_message_template(self, obj):
-        return obj.message.template
-
-    @display(description=_("Render kwargs"))
-    def get_message_render_kwargs(self, obj):
-        return obj.message.render_kwargs
-
     @display(description=_("Title"))
     def get_message_title(self, obj):
         return obj.message.title
@@ -106,8 +98,6 @@ class NotificationAdmin(admin.ModelAdmin):
                         "get_message_type",
                         "get_message_mark",
                         "get_message_content",
-                        "get_message_template",
-                        "get_message_render_kwargs",
                     ]
                 },
             ),
@@ -134,11 +124,10 @@ class MessageAdmin(admin.ModelAdmin):
     list_display = [
         "title",
         "msg_type",
-        "template",
         "mark",
         "created_at",
     ]
-    list_filter = ("msg_type", "template")
+    list_filter = ("msg_type",)
     search_fields = ["mark", "title"]
     ordering = ("-id",)
 
