@@ -7,7 +7,7 @@ from django.core.exceptions import ImproperlyConfigured
 from django.template import Context, Template
 from markdownify import markdownify
 
-from notification.backends.base import BaseNotificationBackend, notify
+from notification.base import BaseNotificationBackend, notify
 from notification.models import Message, MessageTemplate
 
 
