@@ -31,6 +31,7 @@ def notify_by_dummy(
     context: dict = None,
     template_code: str = None,
     save: bool = False,
+    mark: dict = None,
     **kwargs,
 ):
     """
@@ -45,5 +46,6 @@ def notify_by_dummy(
         backends=(DummyNotificationBackend,),
         save=save,
         message_kwargs={},
+        mark=mark,
         **kwargs,
     )
