@@ -106,23 +106,21 @@ class BaseNotificationBackend:
         Send notification to receivers with template
         """
         rendered_content = self.render_template(template, context)
+        title = title or template.title
         message_kwargs = message_kwargs or {}
         if template.message_kwargs:
             message_kwargs = template.message_kwargs.update(message_kwargs)
 
-        title = title or template.title
-        message_content = self.make_content(
-            title, rendered_content, recipients, recipient_field, **message_kwargs
-        )
-        message = self.message_class(
-            title=title,
-            content=message_content,
-            template=template,
-            render_kwargs=context,
+        return self.send(
+            title,
+            recipients,
+            rendered_content,
             mark=mark,
-            msg_type=self.id,
+            save=save,
+            recipient_field=recipient_field,
+            message_kwargs=message_kwargs,
+            **kwargs,
         )
-        self.perform_send(message, recipients, recipient_field, save=save, **kwargs)
 
     def send(
         self,
@@ -206,5 +204,5 @@ def notify(
                 save=save,
                 recipient_field=recipient_field,
                 message_kwargs=message_kwargs,
-                mark=mark
+                mark=mark,
             )
